@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.68 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.69 {
 
   use 5.020;
   use Moose;
@@ -277,6 +277,25 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.68 {
       print STDERR "\n";
     }
 
+    if(-f 'Changes')
+    {
+      my $text = path('Changes')->slurp_utf8;
+      if($text =~ /\}\}\}/)
+      {
+        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
+        print STDERR "Please fix extra } in Changes template";
+        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
+        print STDERR "\n";
+      }
+    }
+    else
+    {
+      print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
+      print STDERR "no Changes file";
+      print STDERR Term::ANSIColor::color('reset') if -t STDERR;
+      print STDERR "\n";
+    }
+
     $self->_my_add_plugin(
       [ 'Author::Plicease::NoUnsafeInc' ],
     );
@@ -319,7 +338,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.68
+version 2.69
 
 =head1 SYNOPSIS
 
@@ -438,7 +457,7 @@ This plugin bundle is mostly equivalent to
  type = gfm
  
  [Author::Plicease::NoUnsafeInc]
- [ArchiveTar]
+ [Libarchive]
 
 =head1 OPTIONS
 
